@@ -18,7 +18,7 @@
      misrepresented as being the original software.
   3. This notice may not be removed or altered from any source distribution.
 */
-#include "../../SDL_internal.h"
+#include "SDL_internal.h"
 
 #ifndef SDL_windowsevents_h_
 #define SDL_windowsevents_h_
@@ -30,10 +30,10 @@ extern HINSTANCE SDL_Instance;
 extern LRESULT CALLBACK WIN_KeyboardHookProc(int nCode, WPARAM wParam, LPARAM lParam);
 extern LRESULT CALLBACK WIN_WindowProc(HWND hwnd, UINT msg, WPARAM wParam,
                                        LPARAM lParam);
-extern void WIN_PumpEvents(_THIS);
-extern void WIN_SendWakeupEvent(_THIS, SDL_Window *window);
-extern int WIN_WaitEventTimeout(_THIS, int timeout);
+extern void WIN_PollRawInput(SDL_VideoDevice *_this, Uint64 poll_start);
+extern void WIN_CheckKeyboardAndMouseHotplug(SDL_VideoDevice *_this, bool initial_check);
+extern void WIN_PumpEvents(SDL_VideoDevice *_this);
+extern void WIN_SendWakeupEvent(SDL_VideoDevice *_this, SDL_Window *window);
+extern int WIN_WaitEventTimeout(SDL_VideoDevice *_this, Sint64 timeoutNS);
 
-#endif /* SDL_windowsevents_h_ */
-
-/* vi: set ts=4 sw=4 expandtab: */
+#endif // SDL_windowsevents_h_
